##  FACT_SHEET_CREATED

```
{
  "id": 42834,
  "type": "FactSheetCreatedEvent",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "createdAt": "2024-02-16T13:12:27.032622Z",
  "factSheet": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 0,
    "name": "AC Management",
    "type": "Application",
    "level": 1,
    "fields": [],
    "status": "ACTIVE",
    "lxState": "BROKEN_QUALITY_SEAL",
    "fullName": "AC Management",
    "naFields": [],
    "createdAt": "2024-02-16T13:12:26.995583770Z",
    "documents": [],
    "relations": [],
    "updatedAt": "2024-02-16T13:12:26.999252278Z",
    "completion": {
      "type": "SectionCompletion",
      "completion": 0.005952380952380952,
      "percentage": 1,
      "totalWeight": 7,
      "weightedSum": 0.041666666666666664,
      "subCompletions": {
        "section.projects": {
          "type": "SectionCompletion",
          "completion": 0,
          "percentage": 0,
          "totalWeight": 1,
          "weightedSum": 0,
          "subCompletions": {
            "subsection.factSheetsAffecting.label": {
              "type": "ConcreteCompletion",
              "completion": 0,
              "percentage": 0,
              "totalWeight": 1,
              "weightedSum": 0
            }
          }
        },
        "section.sourcing": {...},
        "section.information": {...},
        "section.dependencies": {...},
        "section.dataManagement": {...},
        "section.businessSupport": {...},
        "section.lxPortfolioStrategy": {...}
      }
    },
    "milestones": [],
    "displayName": "AC Management",
    "subscriptions": [],
    "permittedReadACL": [],
    "permittedWriteACL": [],
    "lxExcludeFromQuota": false
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "clonedFactSheet": false,
  "transactionSequenceNumber": 75086
}
```



